TimerFunctions
==============

.. toctree::
   :maxdepth: 3

.. automodule:: psyneulink.core.components.functions.nonstateful.timerfunctions
   :members: TimerFunction, LinearTimer, AcceleratingTimer, DeceleratingTimer, AsymptoticTimer
   :private-members:
   :exclude-members: Parameters
